@@ -2,6 +2,7 @@
 // Distributed under Boost license
 
 #include <cassert>
+#include <iostream>
 #include <regex>
 #include <jsoncons/json.hpp>
 
@@ -27,7 +28,7 @@ namespace ns {
         BookCategory category;
         std::string author;
         std::string title;
-        double price;
+        double price{0};
     };
 
     // #2 Class with private member data and default constructor   
@@ -36,11 +37,12 @@ namespace ns {
         BookCategory category_;
         std::string author_;
         std::string title_;
-        double price_;
-        Book2() = default;
+        double price_{0};
 
         JSONCONS_TYPE_TRAITS_FRIEND
     public:
+        Book2() = default;
+
         BookCategory category() const {return category_;}
 
         const std::string& author() const {return author_;}
@@ -163,7 +165,7 @@ namespace ns {
         static std::map<Employee, uint64_t> employee_id_map = {{Employee("John", "Smith"), 1},{Employee("Jane", "Doe"), 2}};
 
         std::vector<uint64_t> ids;
-        for (auto employee : employees)
+        for (const auto& employee : employees)
         {
             ids.push_back(employee_id_map.at(employee));
         }
@@ -280,7 +282,7 @@ void json_type_traits_book_examples()
                   << item.price << "\n";
     }
     std::cout << "\n";
-    encode_json(books1, std::cout, indenting::indent);
+    encode_json_pretty(books1, std::cout);
     std::cout << "\n\n";
 
     std::cout << "(2)\n\n";
@@ -293,7 +295,7 @@ void json_type_traits_book_examples()
                   << item.price() << "\n";
     }
     std::cout << "\n";
-    encode_json(books2, std::cout, indenting::indent);
+    encode_json_pretty(books2, std::cout);
     std::cout << "\n\n";
 
     std::cout << "(3)\n\n";
@@ -306,7 +308,7 @@ void json_type_traits_book_examples()
                   << item.price() << "\n";
     }
     std::cout << "\n";
-    encode_json(books3, std::cout, indenting::indent);
+    encode_json_pretty(books3, std::cout);
     std::cout << "\n\n";
 
     std::cout << "(4)\n\n";
@@ -319,7 +321,7 @@ void json_type_traits_book_examples()
                   << item.getPrice() << "\n";
     }
     std::cout << "\n";
-    encode_json(books4, std::cout, indenting::indent);
+    encode_json_pretty(books4, std::cout);
     std::cout << "\n\n";
 }
 
@@ -351,7 +353,7 @@ void translate_ids_from_to_employees()
     std::cout << "\n";
 
     std::string output;
-    encode_json(company, output, indenting::indent);
+    encode_json_pretty(company, output);
     std::cout << "(2)\n" << output << "\n\n";
 }
 
@@ -381,7 +383,7 @@ void tidy_member()
     std::cout << "\n";
 
     std::string output;
-    encode_json(persons, output, indenting::indent);
+    encode_json_pretty(persons, output);
     std::cout << "(2)\n" << output << "\n";
 
 }
