@@ -7,11 +7,11 @@
 #ifndef JSONCONS_CONFIG_VERSION_HPP
 #define JSONCONS_CONFIG_VERSION_HPP
  
-#include <iostream>
+#include <ostream>
     
 #define JSONCONS_VERSION_MAJOR 1
-#define JSONCONS_VERSION_MINOR 3
-#define JSONCONS_VERSION_PATCH 0
+#define JSONCONS_VERSION_MINOR 4
+#define JSONCONS_VERSION_PATCH 1
 
 namespace jsoncons {
 
