@@ -12,46 +12,59 @@
 #include <cstdint>
 #include <functional> // std::function
 #include <ios>
+#include <ostream> 
 #include <memory> // std::allocator
 #include <system_error>
 #include <type_traits> // std::enable_if
 
 #include <jsoncons/config/compiler_support.hpp>
 #include <jsoncons/conv_error.hpp>
-#include <jsoncons/detail/write_number.hpp>
+#include <jsoncons/utility/write_number.hpp>
 #include <jsoncons/item_event_visitor.hpp>
 #include <jsoncons/json_exception.hpp>
 #include <jsoncons/json_parser.hpp>
-#include <jsoncons/json_type_traits.hpp>
+#include <jsoncons/json_type.hpp>
 #include <jsoncons/json_visitor.hpp>
-#include <jsoncons/ser_context.hpp>
+#include <jsoncons/semantic_tag.hpp>
+#include <jsoncons/ser_util.hpp>
 #include <jsoncons/sink.hpp>
-#include <jsoncons/tag_type.hpp>
 #include <jsoncons/typed_array_view.hpp>
 #include <jsoncons/utility/bigint.hpp>
-#include <jsoncons/utility/extension_traits.hpp>
+#include <jsoncons/utility/more_type_traits.hpp>
 
-#include <jsoncons/value_converter.hpp>
+#include <jsoncons/utility/conversion.hpp>
 
 namespace jsoncons {
 
-enum class staj_event_type
+enum class staj_event_type : uint8_t
 {
-    begin_array,
-    end_array,
-    begin_object,
-    end_object,
-    key,
-    string_value,
-    byte_string_value,
-    null_value,
-    bool_value,
-    int64_value,
-    uint64_value,
-    half_value,
-    double_value
+    key = 0,                // 0000
+    string_value = 1,       // 0001
+    byte_string_value = 2,  // 0010
+    null_value = 3,         // 0011
+    bool_value = 4,         // 0100
+    int64_value = 5,        // 0101
+    uint64_value = 6,       // 0110
+    half_value = 8,         // 1000
+    double_value = 9,       // 1001
+    begin_object = 13,      // 1101
+    end_object = 7,         // 0111    
+    begin_array = 14,       // 1110
+    end_array = 15          // 1111
 };
 
+inline bool is_begin_container(staj_event_type event_type) noexcept
+{
+    static const uint8_t mask{ uint8_t(staj_event_type::begin_object) & uint8_t(staj_event_type::begin_array) };
+    return (uint8_t(event_type) & mask) == mask;
+}
+
+inline bool is_end_container(staj_event_type event_type) noexcept
+{
+    static const uint8_t mask{ uint8_t(staj_event_type::end_object) & uint8_t(staj_event_type::end_array) };
+    return (uint8_t(event_type) & mask) == mask;
+}
+
 template <typename CharT>
 std::basic_ostream<CharT>& operator<<(std::basic_ostream<CharT>& os, staj_event_type tag)
 {
@@ -158,7 +171,8 @@ class basic_staj_event
     } value_;
     std::size_t length_{0};
 public:
-    using string_view_type = jsoncons::basic_string_view<CharT>;
+    using char_type = CharT;
+    using string_view_type = jsoncons::basic_string_view<char_type>;
 
     basic_staj_event(staj_event_type event_type, semantic_tag tag = semantic_tag::none)
         : event_type_(event_type), tag_(tag), value_()
@@ -241,7 +255,7 @@ public:
     {
         std::error_code ec;
         T val = get<T>(ec);
-        if (ec)
+        if (JSONCONS_UNLIKELY(ec))
         {
             JSONCONS_THROW(ser_error(ec));
         }
@@ -255,51 +269,60 @@ public:
     }
 
     template <typename T,typename Allocator,typename CharT_ = CharT>
-    typename std::enable_if<extension_traits::is_string<T>::value && std::is_same<typename T::value_type, CharT_>::value, T>::type
-    get_(Allocator,std::error_code& ec) const
+    typename std::enable_if<ext_traits::is_string<T>::value && std::is_same<typename T::value_type, CharT_>::value, T>::type
+    get_(Allocator alloc,std::error_code& ec) const
     {
+        constexpr const char_type* true_constant = JSONCONS_CSTRING_CONSTANT(char_type,"true"); 
+        constexpr const char_type* false_constant = JSONCONS_CSTRING_CONSTANT(char_type,"false"); 
+        constexpr const char_type* null_constant = JSONCONS_CSTRING_CONSTANT(char_type,"null"); 
+
         switch (event_type_)
         {
             case staj_event_type::key:
             case staj_event_type::string_value:
             {
-                value_converter<jsoncons::basic_string_view<CharT>,T> converter;
-                return converter.convert(jsoncons::basic_string_view<CharT>(value_.string_data_, length_), tag(), ec);
+                return jsoncons::make_obj_using_allocator<T>(alloc, value_.string_data_, length_);
             }
             case staj_event_type::byte_string_value:
             {
-                value_converter<jsoncons::byte_string_view,T> converter;
-                return converter.convert(byte_string_view(value_.byte_string_data_,length_),tag(),ec);
+                auto s = jsoncons::make_obj_using_allocator<T>(alloc);
+                bytes_to_string(value_.byte_string_data_, value_.byte_string_data_+length_, tag(), s);
+                return s;
             }
             case staj_event_type::uint64_value:
             {
-                value_converter<uint64_t,T> converter;
-                return converter.convert(value_.uint64_value_, tag(), ec);
+                auto s = jsoncons::make_obj_using_allocator<T>(alloc);
+                jsoncons::utility::from_integer(value_.uint64_value_, s);
+                return s;
             }
             case staj_event_type::int64_value:
             {
-                value_converter<int64_t,T> converter;
-                return converter.convert(value_.int64_value_, tag(), ec);
+                auto s = jsoncons::make_obj_using_allocator<T>(alloc);
+                jsoncons::utility::from_integer(value_.int64_value_, s);
+                return s;
             }
             case staj_event_type::half_value:
             {
-                value_converter<half_arg_t,T> converter;
-                return converter.convert(value_.half_value_, tag(), ec);
+                auto s = jsoncons::make_obj_using_allocator<T>(alloc);
+                jsoncons::utility::write_double f{float_chars_format::general,0};
+                double x = binary::decode_half(value_.half_value_);
+                f(x, s);
+                return s;
             }
             case staj_event_type::double_value:
             {
-                value_converter<double,T> converter;
-                return converter.convert(value_.double_value_, tag(), ec);
+                auto s = jsoncons::make_obj_using_allocator<T>(alloc);
+                jsoncons::utility::write_double f{float_chars_format::general,0};
+                f(value_.double_value_, s);
+                return s;
             }
             case staj_event_type::bool_value:
             {
-                value_converter<bool,T> converter;
-                return converter.convert(value_.bool_value_,tag(),ec);
+                return jsoncons::make_obj_using_allocator<T>(alloc, value_.bool_value_ ? true_constant : false_constant);
             }
             case staj_event_type::null_value:
             {
-                value_converter<null_type,T> converter;
-                return converter.convert(tag(), ec);
+                return jsoncons::make_obj_using_allocator<T>(alloc, null_constant);
             }
             default:
             {
@@ -310,7 +333,7 @@ public:
     }
 
     template <typename T,typename Allocator,typename CharT_ = CharT>
-    typename std::enable_if<extension_traits::is_string_view<T>::value && std::is_same<typename T::value_type, CharT_>::value, T>::type
+    typename std::enable_if<ext_traits::is_string_view<T>::value && std::is_same<typename T::value_type, CharT_>::value, T>::type
         get_(Allocator, std::error_code& ec) const
     {
         T s;
@@ -345,21 +368,28 @@ public:
     }
 
     template <typename T,typename Allocator>
-    typename std::enable_if<extension_traits::is_array_like<T>::value &&
+    typename std::enable_if<ext_traits::is_array_like<T>::value &&
                             std::is_same<typename T::value_type,uint8_t>::value,T>::type
-    get_(Allocator, std::error_code& ec) const
+    get_(Allocator alloc, std::error_code& ec) const
     {
         switch (event_type_)
         {
-        case staj_event_type::byte_string_value:
+            case staj_event_type::byte_string_value:
             {
-                value_converter<byte_string_view,T> converter;
-                return converter.convert(byte_string_view(value_.byte_string_data_, length_), tag(), ec);
+                auto v = jsoncons::make_obj_using_allocator<T>(alloc, 
+                    value_.byte_string_data_, 
+                    value_.byte_string_data_+length_);
+                return v;
             }
-        case staj_event_type::string_value:
+            case staj_event_type::string_value:
             {
-                value_converter<jsoncons::basic_string_view<CharT>,T> converter;
-                return converter.convert(jsoncons::basic_string_view<CharT>(value_.string_data_, length_), tag(), ec);
+                auto v = jsoncons::make_obj_using_allocator<T>(alloc);
+                auto r = string_to_bytes(value_.string_data_, value_.string_data_+length_, tag(), v);
+                if (r.ec != conv_errc{})
+                {
+                    ec = conv_errc::not_byte_string;
+                }
+                return v;
             }
             default:
                 ec = conv_errc::not_byte_string;
@@ -368,7 +398,7 @@ public:
     }
 
     template <typename IntegerType,typename Allocator>
-    typename std::enable_if<extension_traits::is_integer<IntegerType>::value, IntegerType>::type
+    typename std::enable_if<ext_traits::is_integer<IntegerType>::value, IntegerType>::type
     get_(Allocator, std::error_code& ec) const
     {
         switch (event_type_)
@@ -376,7 +406,7 @@ public:
             case staj_event_type::string_value:
             {
                 IntegerType val;
-                auto result = jsoncons::detail::to_integer(value_.string_data_, length_, val);
+                auto result = jsoncons::utility::to_integer(value_.string_data_, length_, val);
                 if (!result)
                 {
                     ec = conv_errc::not_integer;
@@ -408,7 +438,7 @@ public:
     }
 
     template <typename T,typename Allocator>
-    typename std::enable_if<extension_traits::is_bool<T>::value, T>::type
+    typename std::enable_if<ext_traits::is_bool<T>::value, T>::type
         get_(Allocator, std::error_code& ec) const
     {
         return as_bool(ec);
@@ -429,8 +459,9 @@ private:
             case staj_event_type::key:
             case staj_event_type::string_value:
             {
-                jsoncons::detail::chars_to f;
-                return f(value_.string_data_, length_);
+                double val{0};
+                jsoncons::utility::decstr_to_double(value_.string_data_, length_, val);
+                return val;
             }
             case staj_event_type::double_value:
                 return value_.double_value_;
@@ -467,77 +498,103 @@ private:
         }
     }
 public:
-    bool send_json_event(basic_json_visitor<CharT>& visitor,
+    void send_json_event(basic_json_visitor<CharT>& visitor,
         const ser_context& context,
         std::error_code& ec) const
     {
         switch (event_type())
         {
             case staj_event_type::begin_array:
-                return visitor.begin_array(tag(), context);
+                visitor.begin_array(tag(), context);
+                break;
             case staj_event_type::end_array:
-                return visitor.end_array(context);
+                visitor.end_array(context);
+                break;
             case staj_event_type::begin_object:
-                return visitor.begin_object(tag(), context, ec);
+                visitor.begin_object(tag(), context, ec);
+                break;
             case staj_event_type::end_object:
-                return visitor.end_object(context, ec);
+                visitor.end_object(context, ec);
+                break;
             case staj_event_type::key:
-                return visitor.key(string_view_type(value_.string_data_,length_), context);
+                visitor.key(string_view_type(value_.string_data_,length_), context);
+                break;
             case staj_event_type::string_value:
-                return visitor.string_value(string_view_type(value_.string_data_,length_), tag(), context);
+                visitor.string_value(string_view_type(value_.string_data_,length_), tag(), context);
+                break;
             case staj_event_type::byte_string_value:
-                return visitor.byte_string_value(byte_string_view(value_.byte_string_data_,length_), tag(), context);
+                visitor.byte_string_value(byte_string_view(value_.byte_string_data_,length_), tag(), context);
+                break;
             case staj_event_type::null_value:
-                return visitor.null_value(tag(), context);
+                visitor.null_value(tag(), context);
+                break;
             case staj_event_type::bool_value:
-                return visitor.bool_value(value_.bool_value_, tag(), context);
+                visitor.bool_value(value_.bool_value_, tag(), context);
+                break;
             case staj_event_type::int64_value:
-                return visitor.int64_value(value_.int64_value_, tag(), context);
+                visitor.int64_value(value_.int64_value_, tag(), context);
+                break;
             case staj_event_type::uint64_value:
-                return visitor.uint64_value(value_.uint64_value_, tag(), context);
+                visitor.uint64_value(value_.uint64_value_, tag(), context);
+                break;
             case staj_event_type::half_value:
-                return visitor.half_value(value_.half_value_, tag(), context);
+                visitor.half_value(value_.half_value_, tag(), context);
+                break;
             case staj_event_type::double_value:
-                return visitor.double_value(value_.double_value_, tag(), context);
+                visitor.double_value(value_.double_value_, tag(), context);
+                break;
             default:
-                return false;
+                break;
         }
     }
     
-    bool send_value_event(basic_item_event_visitor<CharT>& visitor,
+    void send_value_event(basic_item_event_visitor<CharT>& visitor,
         const ser_context& context,
         std::error_code& ec) const
     {
         switch (event_type())
         {
             case staj_event_type::key:
-                return visitor.string_value(string_view_type(value_.string_data_,length_), tag(), context);
+                visitor.string_value(string_view_type(value_.string_data_,length_), tag(), context);
+                break;
             case staj_event_type::begin_array:
-                return visitor.begin_array(tag(), context);
+                visitor.begin_array(tag(), context);
+                break;
             case staj_event_type::end_array:
-                return visitor.end_array(context);
+                visitor.end_array(context);
+                break;
             case staj_event_type::begin_object:
-                return visitor.begin_object(tag(), context, ec);
+                visitor.begin_object(tag(), context, ec);
+                break;
             case staj_event_type::end_object:
-                return visitor.end_object(context, ec);
+                visitor.end_object(context, ec);
+                break;
             case staj_event_type::string_value:
-                return visitor.string_value(string_view_type(value_.string_data_,length_), tag(), context);
+                visitor.string_value(string_view_type(value_.string_data_,length_), tag(), context);
+                break;
             case staj_event_type::byte_string_value:
-                return visitor.byte_string_value(byte_string_view(value_.byte_string_data_,length_), tag(), context);
+                visitor.byte_string_value(byte_string_view(value_.byte_string_data_,length_), tag(), context);
+                break;
             case staj_event_type::null_value:
-                return visitor.null_value(tag(), context);
+                visitor.null_value(tag(), context);
+                break;
             case staj_event_type::bool_value:
-                return visitor.bool_value(value_.bool_value_, tag(), context);
+                visitor.bool_value(value_.bool_value_, tag(), context);
+                break;
             case staj_event_type::int64_value:
-                return visitor.int64_value(value_.int64_value_, tag(), context);
+                visitor.int64_value(value_.int64_value_, tag(), context);
+                break;
             case staj_event_type::uint64_value:
-                return visitor.uint64_value(value_.uint64_value_, tag(), context);
+                visitor.uint64_value(value_.uint64_value_, tag(), context);
+                break;
             case staj_event_type::half_value:
-                return visitor.half_value(value_.half_value_, tag(), context);
+                visitor.half_value(value_.half_value_, tag(), context);
+                break;
             case staj_event_type::double_value:
-                return visitor.double_value(value_.double_value_, tag(), context);
+                visitor.double_value(value_.double_value_, tag(), context);
+                break;
             default:
-                return false;
+                break;
         }
     }
 
