@@ -18,10 +18,11 @@
 
 #include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/item_event_visitor.hpp>
+#include <jsoncons/json_type.hpp>
 #include <jsoncons/json_visitor.hpp>
-#include <jsoncons/ser_context.hpp>
+#include <jsoncons/semantic_tag.hpp>
+#include <jsoncons/ser_util.hpp>
 #include <jsoncons/source.hpp>
-#include <jsoncons/tag_type.hpp>
 #include <jsoncons/utility/binary.hpp>
 #include <jsoncons/utility/unicode_traits.hpp>
 
@@ -29,7 +30,8 @@
 #include <jsoncons_ext/cbor/cbor_error.hpp>
 #include <jsoncons_ext/cbor/cbor_options.hpp>
 
-namespace jsoncons { namespace cbor {
+namespace jsoncons { 
+namespace cbor {
 
 enum class parse_mode {root,accept,array,indefinite_array,map_key,map_value,indefinite_map_key,indefinite_map_value,multi_dim};
 
@@ -1219,7 +1221,7 @@ private:
                 {
                     return;
                 }
-                jsoncons::detail::from_integer(val, str);
+                jsoncons::utility::from_integer(val, str);
                 break;
             }
             case jsoncons::cbor::detail::cbor_major_type::negative_integer:
@@ -1229,7 +1231,7 @@ private:
                 {
                     return;
                 }
-                jsoncons::detail::from_integer(val, str);
+                jsoncons::utility::from_integer(val, str);
                 break;
             }
             case jsoncons::cbor::detail::cbor_major_type::semantic_tag:
@@ -1294,11 +1296,11 @@ private:
             if (str[0] == '-')
             {
                 result.push_back('-');
-                jsoncons::detail::prettify_string(str.c_str()+1, str.size()-1, (int)exponent, -4, 17, result);
+                jsoncons::utility::prettify_string(str.c_str()+1, str.size()-1, (int)exponent, -4, 17, result);
             }
             else
             {
-                jsoncons::detail::prettify_string(str.c_str(), str.size(), (int)exponent, -4, 17, result);
+                jsoncons::utility::prettify_string(str.c_str(), str.size(), (int)exponent, -4, 17, result);
             }
         }
         else
@@ -1377,7 +1379,7 @@ private:
                 }
                 str.push_back('0');
                 str.push_back('x');
-                jsoncons::detail::integer_to_hex(val, str);
+                jsoncons::utility::integer_to_hex(val, str);
                 break;
             }
             case jsoncons::cbor::detail::cbor_major_type::negative_integer:
@@ -1390,7 +1392,7 @@ private:
                 str.push_back('-');
                 str.push_back('0');
                 str.push_back('x');
-                jsoncons::detail::integer_to_hex(static_cast<uint64_t>(-val), str);
+                jsoncons::utility::integer_to_hex(static_cast<uint64_t>(-val), str);
                 break;
             }
             case jsoncons::cbor::detail::cbor_major_type::semantic_tag:
@@ -1451,12 +1453,12 @@ private:
         str.push_back('p');
         if (exponent >=0)
         {
-            jsoncons::detail::integer_to_hex(static_cast<uint64_t>(exponent), str);
+            jsoncons::utility::integer_to_hex(static_cast<uint64_t>(exponent), str);
         }
         else
         {
             str.push_back('-');
-            jsoncons::detail::integer_to_hex(static_cast<uint64_t>(-exponent), str);
+            jsoncons::utility::integer_to_hex(static_cast<uint64_t>(-exponent), str);
         }
     }
 
