@@ -8,6 +8,7 @@
 #include <vector>
 #include <utility>
 #include <ctime>
+#include <iostream>
 
 using namespace jsoncons;
 
@@ -21,12 +22,12 @@ TEST_CASE("test_byte_string_serialization")
 
     std::string expected; 
     expected.push_back('\"');
-    encode_base64url(bytes.begin(),bytes.end(),expected);
+    bytes_to_base64url(bytes.begin(),bytes.end(),expected);
     expected.push_back('\"');
 
     //std::cout << expected << " " << os.str() << '\n';
 
-    CHECK(os.str() == expected);
+    CHECK(expected == os.str());
 }
 
 struct json_string_encoder_reset_test_fixture
