@@ -3,6 +3,7 @@
 
 #include <jsoncons/json.hpp>
 #include <jsoncons/json_reader.hpp>
+#include <iostream>
 #include <catch/catch.hpp>
 
 using namespace jsoncons; 
@@ -253,9 +254,9 @@ TEST_CASE("test_read_primitive_fail")
     test_json_reader_error("true []", jsoncons::json_errc::extra_character);
     test_json_reader_error("tru ", jsoncons::json_errc::invalid_value);
     test_json_reader_error("10 {}", jsoncons::json_errc::extra_character);
-    test_json_reader_error("1a ", jsoncons::json_errc::invalid_number);
+    test_json_reader_error("1a ", jsoncons::json_errc::extra_character);
     test_json_reader_error("1.999 []", jsoncons::json_errc::extra_character);
-    test_json_reader_error("1e0-1", jsoncons::json_errc::invalid_number);
+    test_json_reader_error("1e0-1", jsoncons::json_errc::extra_character);
     test_json_reader_error("\"string\"{}", jsoncons::json_errc::extra_character);
     test_json_reader_error("\"string\"[]", jsoncons::json_errc::extra_character);
 }
@@ -354,10 +355,10 @@ TEST_CASE("json_reader json lines")
 #if defined(JSONCONS_HAS_STATEFUL_ALLOCATOR) && JSONCONS_HAS_STATEFUL_ALLOCATOR == 1
 
 #include <scoped_allocator>
-#include <common/free_list_allocator.hpp>
+#include <common/mock_stateful_allocator.hpp>
 
 template <typename T>
-using MyScopedAllocator = std::scoped_allocator_adaptor<free_list_allocator<T>>;
+using MyScopedAllocator = std::scoped_allocator_adaptor<mock_stateful_allocator<T>>;
 
 TEST_CASE("json_reader stateful allocator tests")
 {
